@@ -15,13 +15,13 @@ checkNull = function(x) {
 
 #' @rdname checkNull
 #' @export
-assertNull = function(x, .var.name) {
+assertNull = function(x, add = NULL, .var.name) {
   res = checkNull(x)
-  makeAssertion(res, vname(x, .var.name))
+  makeAssertion(res, vname(x, .var.name), add)
 }
 
 #' @rdname checkNull
 #' @export
 testNull = function(x) {
-  isTRUE(checkNull(x))
+  is.null(x)
 }
