@@ -2,6 +2,7 @@
 #define CHECKMATE_ANY_MISSING_H_
 
 #include <R.h>
+#define USE_RINTERNALS
 #include <Rinternals.h>
 
 Rboolean any_missing_logical(SEXP);
@@ -15,6 +16,7 @@ Rboolean any_missing_atomic(SEXP);
 Rboolean any_missing_list(SEXP);
 Rboolean any_missing_matrix(SEXP);
 Rboolean any_missing_frame(SEXP);
+Rboolean any_missing(SEXP);
 SEXP c_any_missing(SEXP);
 
 #endif
