@@ -63,8 +63,33 @@ test_that("allMissing", {
   expect_false(allMissing(xm))
   expect_false(allMissing(xf))
 
+  xb[] = xi[] = xd[] = xc[] = xm[] = xs = NA
+  xl = list(NULL, NULL)
+  xf$a = xf$b = NA
+
+  expect_true(allMissing(xb))
+  expect_true(allMissing(xi))
+  expect_true(allMissing(xd))
+  expect_true(allMissing(xc))
+  expect_true(allMissing(xs))
+  expect_true(allMissing(xl))
+  expect_true(allMissing(xm))
+  expect_true(allMissing(xf))
 
   expect_false(allMissing(as.raw(1)))
   expect_false(allMissing(NULL))
   expect_error(allMissing(as.symbol("a")), "supported")
 })
+
+test_that("anyMissing and allMissing work correctly with data.frames", {
+  df = data.frame(a = 1:2, b = 2:1)
+  expect_false(anyMissing(df))
+  expect_false(allMissing(df))
+  df$b[1] = NA
+  expect_true(anyMissing(df))
+  expect_false(allMissing(df))
+  df$b[2] = NA
+  expect_true(anyMissing(df))
+  expect_true(allMissing(df))
+  expect_false(all(sapply(df, allMissing)))
+})
